Function wavefc::helpers::arrayify

source ·
pub fn arrayify<T>(
    input: Vec<(T, Vector2<usize>)>,
    size: &Vector2<usize>
) -> Vec<Vec<T>>
Returns all the possible shifted possibilities of the given 2D array. Converts the given flat vector of T and Vector2 pairs into a 2-dimensional vector of just T.

Debug-wise, this function will also assert that its input doesn’t contain any duplicate Vector2s. This check only occurs in debug mode.