Structs
Adjacency information and data about a given chunk.
Enums
Various modes for analyzing adjacencies at the border of a 2d array.
Functions
Returns all the possible shifted possibilities of the given 2D array.
Converts the given flat vector of
T and Vector2 pairs into a 2-dimensional vector of just T.This function finds the width and height of the given 2D array.
Converts the 2-dimensional array into chunked, square patterns of the specified size.
Shifts the given grid by the number of times specified along the different axis.